
/*
    smbus.h - Part of a Linux module for reading sensor data.
    Copyright (c) 1998  Alexander Larsson <alla@lysator.liu.se>,
    Frodo Looijaard <frodol@dds.nl> and Philip Edelbrock <phil@netroedge.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef __LINUX_SMBUS_H
#define __LINUX_SMBUS_H

/*
	Prototypes 
*/
extern int SMBus_Init(void);
extern void SMBus_Cleanup(void);
extern int SMBus_Write(int addr, long value, int size);
extern int SMBus_Read(int addr, int command, int size);

extern int SMBus_Initialized;

/* SMBus transaction types (size parameter in the above functions) */
#define SMBUS_QUICK_WRITE 0x00
#define SMBUS_BYTE       0x04
#define SMBUS_BYTE_DATA  0x08 
#define SMBUS_WORD_DATA  0x0C
#define SMBUS_BLOCK_DATA 0x14

extern int check_smbus(unsigned int address);
extern void request_smbus(unsigned int address, const char *name);
extern void release_smbus(unsigned int address);

/* Some functions to make things easier */
#define SMBus_Quick_Write(addr,command) \
           (printk("SMBus quick write command not yet implemented\n"),-1)

#define SMBus_Read_Simple(addr) \
           (printk("SMBus simple read command not yet implemented\n"),-1)

#define SMBus_Write_Simple(addr) \
           (printk("SMBus simple write command not yet implemented\n"),-1)

#define SMBus_Read_Byte(addr,command) \
           SMBus_Read(addr,command,SMBUS_BYTE_DATA)

#define SMBus_Read_Word(addr,command) \
           SMBus_Read(addr,command,SMBUS_WORD_DATA)

#define SMBus_Write_Byte(addr,command,value) \
           SMBus_Write(addr,((command) & 0xff) | (((value) & 0xff) << 8), \
                       SMBUS_BYTE_DATA)

#define SMBus_Write_Word(addr,command,value) \
           SMBus_Write(addr,((command) & 0xff) | (((value) & 0xffff) << 8), \
                       SMBUS_WORD_DATA)

#define SMBus_Process_Call(addr,command,value) \
        (printk("Warning! SMBus process call emulated\n"), \
        (SMBus_Write_Word(addr,command,value) < 0 ? -1 : \
                          SMBus_Read_Word(addr,command);

#define SMBus_Read_Block(addr,command,count,valueptr) \
        (printk("SMBus read block command not yet implemented\n"), -1)

#define SMBus_Write_Block(addr,command,count,valueptr) \
        (printk("SMBus write block command not yet implemented\n"), -1)
#endif
